@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "empv" "6.1.0"
+(define-package "empv" "20251116.2314"
   "A multimedia player/manager, YouTube interface."
   '((emacs  "28.1")
     (s      "1.13.0")
     (compat "29.1.4.4"))
   :url "https://github.com/isamert/empv.el"
-  :commit "11245762388c03ecdfb550fb1b96978459d68a4f"
-  :revdesc "11245762388c"
+  :commit "6b40d9e6f8d479eb22a8649fb92de513d3fc2b44"
+  :revdesc "6b40d9e6f8d4"
   :authors '(("Isa Mert Gurbuz" . "isamertgurbuz@gmail.com"))
   :maintainers '(("Isa Mert Gurbuz" . "isamertgurbuz@gmail.com")))
